@@ -1,6 +1,7 @@
 package Pcore::App::Redis;
 
 use Pcore -class;
+use Pcore::Redis;
 
 extends qw[Pcore::App::Alien];
 
@@ -16,12 +17,16 @@ our $CFG = {
 };
 
 # CLI
-sub cli_name ($self) {
-    return 'redis';
-}
+around CLI => sub ( $orig, $self ) {
+    my $cli = $self->$orig;
+
+    $cli->{name} = 'redis';
+
+    return $cli;
+};
 
 sub _build_redis_ver ($self) {
-    return $self->cfg->{REDIS}->{REDIS_VER} || $ENV->{CFG}->{REDIS}->{REDIS_VER};
+    return $self->cfg->{REDIS}->{REDIS_VER} || $ENV->get_dist('pcore-redis')->cfg->{REDIS}->{REDIS_VER};
 }
 
 # APP
